<!-- identity password_policys -->
<script id="services.identity.password_policy.details.template" type="text/x-handlebars-template">
    <div class="list-group" id="services.identity.password_policy.details">
        <div class="list-group" id="services.identity.password_policy.view">
            <div class="list-group-item active">
                <h4 class="list-group-item-heading">Password policy</h4>
            </div>
            <div class="list-group-item">
                <div class="list-group-item-text item-margin">Minimum Password Length: <span id="identity.password_policy.minimum_password_length"><samp>{{items.minimum_password_length}}</samp></span></div>
                <div class="list-group-item-text item-margin">May contain username: <span id="identity.password_policy.is_username_containment_allowed"><samp>{{items.is_username_containment_allowed}}</samp></span></div>
                <div class="list-group-item-text item-margin">Must contain at least 1 numeric character: <span id="identity.password_policy.is_numeric_characters_required"><samp>{{items.is_numeric_characters_required}}</samp></span></div>
                <div class="list-group-item-text item-margin">Must contain at least 1 special character: <span id="identity.password_policy.is_special_characters_required"><samp>{{items.is_special_characters_required}}</samp></span></div>
                <div class="list-group-item-text item-margin">Must contain at least 1 uppercase character: <span id="identity.password_policy.is_uppercase_characters_required"><samp>{{items.is_uppercase_characters_required}}</samp></span></div>
                <div class="list-group-item-text item-margin">Must contain at least 1 lowercase character: <span id="identity.password_policy.is_lowercase_characters_required"><samp>{{items.is_lowercase_characters_required}}</samp></span></div>

            </div>
        </div></div>
</script>

