<!-- Account password policy -->
<script id="services.ram.password_policy.details.template" type="text/x-handlebars-template">
  <div class="list-group" id="services.ram.password_policy.details">
    <div class="list-group" id="services.ram.password_policy.view">
      <div class="list-group-item active">
        <h4 class="list-group-item-heading">Password policy</h4>
      </div>
      <div class="list-group-item">
        <div class="list-group-item-text item-margin">Minimum password length: <span id="ram.password_policy.minimum_password_length">{{items.minimum_password_length}}</span></div>
        <div class="list-group-item-text item-margin">Maximum login attempts: <span id="ram.password_policy.max_login_attempts">{{items.max_login_attempts}} (a value of 0 indicates that the password retry constraint is disabled)</span></div>
        <div class="list-group-item-text item-margin">Password expiration period (in days): <span id="ram.password_policy.max_password_age">{{items.max_password_age}} (a value of 0 indicates that the password never expires)</span></div>
        <div class="list-group-item-text item-margin">Disable Logon after Password Expiration: <span id="ram.password_policy.hard_expiry"><samp>{{items.hard_expiry}}</samp></span></div>
        <div class="list-group-item-text item-margin">Prevent password reuse: <span id="ram.password_policy.password_reuse_prevention"><samp>{{items.password_reuse_prevention}}</samp>
            {{#if items.password_reuse_prevention}}
             (users not allowed to use the latest <b>{{items.password_reuse_count}}</b> passwords)
            {{/if}}
        </span>
        </div>
        <div class="list-group-item-text item-margin">Require at least one uppercase letter: <span id="ram.password_policy.require_uppercase_characters"><samp>{{items.require_uppercase_characters}}</samp></span></div>
        <div class="list-group-item-text item-margin">Require at least one lowercase letter: <span id="ram.password_policy.require_lowercase_characters"><samp>{{items.require_lowercase_characters}}</samp></span></div>
        <div class="list-group-item-text item-margin">Require at least one number: <span id="ram.password_policy.require_numbers"><samp>{{items.require_numbers}}</samp></span></div>
        <div class="list-group-item-text item-margin">Require at least one non-alphanumeric character: <span id="ram.password_policy.require_symbols"><samp>{{items.require_symbols}}</samp></span></div>
      </div>
    </div></div>
</script>