
<!-- graphrbac users -->
<script id="services.graphrbac.users.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">User Principal Name: <span id="graphrbac.users.{{@key}}.user_principal_name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Display Name: <span id="graphrbac.users.{{@key}}.display_name"><samp>{{value_or_none display_name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Mail Nickname: <span id="graphrbac.users.{{@key}}.mail_nickname"><samp>{{value_or_none mail_nickname}}</samp></span></div>
        <div class="list-group-item-text item-margin">Given Name: <span id="graphrbac.users.{{@key}}.given_name"><samp>{{value_or_none given_name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Surname: <span id="graphrbac.users.{{@key}}.surname"><samp>{{value_or_none surname}}</samp></span></div>
        <div class="list-group-item-text item-margin">Mail: <span id="graphrbac.users.{{@key}}.mail"><samp>{{value_or_none mail}}</samp></span></div>
        <div class="list-group-item-text item-margin">Sign In Names: <span id="graphrbac.users.{{@key}}.sign_in_names"><samp>{{value_or_none sign_in_names}}</samp></span></div>
        <div class="list-group-item-text item-margin">User Type: <span id="graphrbac.users.{{@key}}.user_type"><samp>{{value_or_none user_type}}</samp></span></div>
        <div class="list-group-item-text item-margin">Usage Location: <span id="graphrbac.users.{{@key}}.usage_location"><samp>{{value_or_none usage_location}}</samp></span></div>
        <div class="list-group-item-text item-margin">Account Enabled: <span id="graphrbac.users.{{@key}}.account_enabled"><samp>{{value_or_none account_enabled}}</samp></span></div>
        <div class="list-group-item-text item-margin">Deletion Timestamp: <span id="graphrbac.users.{{@key}}.deletion_timestamp"><samp>{{value_or_none deletion_timestamp}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.graphrbac.users", $("#services\\.graphrbac\\.users\\.partial").html());
</script>

<!-- Single graphrbac user template -->
<script id="single_graphrbac_user-template" type="text/x-handlebars-template">
    {{> modal-template template='services.graphrbac.users'}}
</script>
<script>
    var single_graphrbac_user_template = Handlebars.compile($("#single_graphrbac_user-template").html());
</script>
