
    <!-- RDS parameter group partial -->
    <script id="services.rds.regions.id.parameter_groups.partial" type="text/x-handlebars-template">
        <div class="list-group-item active">
            <h4 class="list-group-item-heading">{{name}}</h4>
        </div>
        <div class="list-group-item">
            <h4 class="list-group-item-heading">Information</h4>
            <div class="list-group-item-text">Group family: {{DBParameterGroupFamily}}</div>
            <div class="list-group-item-text">Description: {{Description}}</div>
            <div class="list-group-item-text">ARN: {{arn}}</div>
        </div>
        <div class="list-group-item">
            <div class="accordion">
                <h4 class="list-group-item-heading accordion-heading">Parameters</h4>
                <div class="accordion-body item-margin">
                    <div class="accordion-inner">
                        <table class="table-striped" width="100%" >
                            <tr>
                                <td width="20%">Name</td>
                                <td width="20%">Value</td>
                                <td width="60%">Description</td>
                            </tr>
                            {{#each parameters}}
                            <tr>
                                <td width="20%">{{@key}}</td>
                                <td width="20%">{{ParameterValue}}</td>
                                <td width="60%">{{Description}}</td>
                            </tr>
                            {{/each}}
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </script>
    <script>
      Handlebars.registerPartial("services.rds.regions.id.parameter_groups", $("#services\\.rds\\.regions\\.id\\.parameter_groups\\.partial").html());
    </script>

