
<!-- Compute Engine subnetworks partial -->
<script id="services.computeengine.projects.id.regions.id.subnetworks.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">ID: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.id">{{id}}</span></div>
        <div class="list-group-item-text item-margin">Project ID: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.project_id">{{project_id}}</span></div>
        <div class="list-group-item-text item-margin">Name: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.name">{{name}}</span></div>
        <div class="list-group-item-text item-margin">Subnetwork: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.subnetwork">{{subnetwork}}</span></div>
        <div class="list-group-item-text item-margin">Region: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.region">{{region}}</span></div>
        <div class="list-group-item-text item-margin">Gateway Address: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.gateway_address">{{gateway_address}}</span></div>
        <div class="list-group-item-text item-margin">IP Range: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.ip_range">{{ip_range}}</span></div>
        <div class="list-group-item-text item-margin">Private Google Access: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.private_ip_google_access_disabled">{{convert_bool_to_enabled private_ip_google_access}}</span></div>
        <div class="list-group-item-text item-margin">Creation Date: <span id="computeengine.projects.{{@../../key}}.regions.{{@../key}}.subnetworks.{{@key}}.creation_timestamp">{{creation_timestamp}}</span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.computeengine.projects.id.regions.id.subnetworks", $("#services\\.computeengine\\.projects\\.id\\.regions\\.id\\.subnetworks\\.partial").html());
</script>

<!-- Single computeengine subnetwork template -->
<script id="single_computeengine_subnetwork-template" type="text/x-handlebars-template">
    {{> modal-template template='services.computeengine.projects.id.regions.id.subnetworks'}}
</script>
<script>
    var single_computeengine_subnetwork_template = Handlebars.compile($("#single_computeengine_subnetwork-template").html());
</script>
