<!-- route53 hosted_zones -->
<script id="services.route53.regions.id.hosted_zones.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">ID: <span id="route53.regions.id.hosted_zones.{{@key}}.id"><samp>{{value_or_none id}}</samp></span></div>
        <div class="list-group-item-text item-margin">Caller Reference: <span id="route53.regions.id.hosted_zones.{{@key}}.caller_reference"><samp>{{value_or_none caller_reference}}</samp></span></div>
        <div class="list-group-item-text item-margin">Resource Record Set Count: <span id="route53.regions.id.hosted_zones.{{@key}}.resource_record_set_count"><samp>{{value_or_none resource_record_set_count}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.route53.regions.id.hosted_zones", $("#services\\.route53\\.regions\\.id\\.hosted_zones\\.partial").html());
</script>

<!-- Single route53 hosted_zone template -->
<script id="single_route53_hosted_zone-template" type="text/x-handlebars-template">
    {{> modal-template template='services.route53.regions.id.hosted_zones'}}
</script>
<script>
    var single_route53_hosted_zone_template = Handlebars.compile($("#single_route53_hosted_zone-template").html());
</script>