
    <!-- VPC Subnet partial -->
    <script id="services.vpc.regions.id.vpcs.id.subnets.partial" type="text/x-handlebars-template">
        <div id="resource-name" class="list-group-item active">
            <h4 class="list-group-item-heading">{{name}}</h4>
        </div>
            <div class="list-group-item">
                <h4 class="list-group-item-heading">Information</h4>
                <div class="list-group-item-text">ID: {{name}}</div>
                <div class="list-group-item-text">VPC ID: {{VpcId}}</div>
                <div class="list-group-item-text">Availability Zone: {{AvailabilityZone}}</div>
                <div class="list-group-item-text">CIDR Block: {{CidrBlock}}</div>
                <div class="list-group-item-text">IPv6 CIDR Block: {{Ipv6CidrBlockAssociationSet}}</div>
                <div class="list-group-item-text">Public IP on launch: {{MapPublicIpOnLaunch}}</div>
            </div>
            <div class="list-group-item">
                <h4 class="list-group-item-heading accordion-heading">Instances
                    {{> count_badge count=instances.length}}
                </h4>
                <ul>
                    {{#each instances}}
                        <li class="list-group-item-text"><a href="javascript:showObject('services.ec2.regions.{{../region}}.vpcs.{{../vpc}}.instances.{{this}}')">
                        {{getValueAt 'services.ec2.regions' ../region 'vpcs' ../vpc 'instances' this 'name'}}
                        </a></li>
                    {{/each}}
                </ul>
            </div>
            <div class="list-group-item">
                <h4 class="list-group-item-heading accordion-heading">Flow logs
                    {{> count_badge count=flow_logs.length}}
                </h4>
                <ul>
                    {{#each flow_logs}}
                        <li><a href="javascript:showObject('services.vpc.regions.{{../region}}.flow_logs.{{this.name}}')">{{this.name}}</a></li>
                    {{/each}}
                </ul>
            </div>
    </script>
    <script>
      Handlebars.registerPartial("services.vpc.regions.id.vpcs.id.subnets", $("#services\\.vpc\\.regions\\.id\\.vpcs\\.id\\.subnets\\.partial").html());
    </script>

    <!-- Single VPC Subnet template -->
    <script id="single_vpc_subnet-template" type="text/x-handlebars-template">
        {{> modal-template template='services.vpc.regions.id.vpcs.id.subnets'}}
    </script>
    <script>
        var single_vpc_subnet_template = Handlebars.compile($("#single_vpc_subnet-template").html());
    </script>
