

<!-- network watchers -->
<script id="services.network.watchers.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="network.watchers.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Provisioning State: <span id="network.watchers.{{@key}}.provisioning_state"><samp>{{value_or_none provisioning_state}}</samp></span></div>
        <div class="list-group-item-text item-margin">Location: <span id="network.watchers.{{@key}}.location"><samp>{{value_or_none location}}</samp></span></div>
        <div class="list-group-item-text item-margin">Tags: <span id="network.watchers.{{@key}}.tags"><samp>{{value_or_none tags}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.network.watchers", $("#services\\.network\\.watchers\\.partial").html());
</script>

<!-- Single network watcher template -->
<script id="single_network_watcher-template" type="text/x-handlebars-template">
    {{> modal-template template='services.network.watchers'}}
</script>
<script>
    var single_network_watcher_template = Handlebars.compile($("#single_network_watcher-template").html());
</script>
