
<!-- network virtual_networks -->
<script id="services.network.virtual_networks.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="network.virtual_networks.{{@key}}.name"><samp>{{name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Resource GUID: <span id="network.virtual_networks.{{@key}}.resource_guid"><samp>{{resource_guid}}</samp></span></div>
        <div class="list-group-item-text item-margin">Type: <span id="network.virtual_networks.{{@key}}.type"><samp>{{type}}</samp></span></div>
        <div class="list-group-item-text item-margin">Location: <span id="network.virtual_networks.{{@key}}.location"><samp>{{location}}</samp></span></div>
        <div class="list-group-item-text item-margin">Provisioning State: <span id="network.virtual_networks.{{@key}}.provisioning_state"><samp>{{provisioning_state}}</samp></span></div>
        <div class="list-group-item-text item-margin">Address Space: <span id="network.virtual_networks.{{@key}}.address_space"><samp>{{address_space.address_prefixes}}</samp></span></div>
        <div class="list-group-item-text item-margin">DHCP Options: <span id="network.virtual_networks.{{@key}}.dhcp_options"><samp>{{value_or_none dhcp_options}}</samp></span></div>
        <div class="list-group-item-text item-margin">Virtual Network Peerings: <span id="network.virtual_networks.{{@key}}.virtual_network_peerings"><samp>{{value_or_none virtual_network_peerings}}</samp></span></div>
        <div class="list-group-item-text item-margin">Enable VM Protection: <span id="network.virtual_networks.{{@key}}.enable_vm_protection"><samp>{{enable_vm_protection}}</samp></span></div>
        <div class="list-group-item-text item-margin">Enable DDoS Protection: <span id="network.virtual_networks.{{@key}}.enable_ddos_protection"><samp>{{enable_ddos_protection}}</samp></span></div>
        <div class="list-group-item-text item-margin">DDoS Protection Plan: <span id="network.virtual_networks.{{@key}}.ddos_protection_plan"><samp>{{value_or_none ddos_protection_plan}}</samp></span></div>
        <div class="list-group-item-text item-margin">Tags: <span id="network.virtual_networks.{{@key}}.tags"><samp>{{value_or_none tags}}</samp></span></div>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Subnets</h4>
        {{#each subnets}}
        <div class="list-group-item-text item-margin"><a href="javascript:showObject('services.network.virtual_networks.{{@../key}}.subnets.{{this.id}}')"><samp>{{getValueAt 'services.network.virtual_networks' @../key 'subnets' this.id 'name'}}</samp></a></div>
        {{/each}}
    </div>
</script>

<script>
    Handlebars.registerPartial("services.network.virtual_networks", $("#services\\.network\\.virtual_networks\\.partial").html());
</script>

<!-- Single network virtual_network template -->
<script id="single_network_virtual_network-template" type="text/x-handlebars-template">
    {{> modal-template template='services.network.virtual_networks'}}
</script>
<script>
    var single_network_virtual_network_template = Handlebars.compile($("#single_network_virtual_network-template").html());
</script>
